import React, { forwardRef, useEffect, useRef, useImperativeHandle } from 'react';
import classNames from 'classnames';
// import * as echarts from 'echarts';
// 按需导入模块
// 引入 echarts 核心模块，核心模块提供了 echarts 使用必须要的接口。
import * as echarts from 'echarts/core';
// 引入图表，图表后缀都为 Chart
import { BarChart, PieChart } from 'echarts/charts';
// 引入提示框，标题，直角坐标系，数据集，内置数据转换器组件，组件后缀都为 Component
import {
  TitleComponent,
  TooltipComponent,
  GridComponent,
  DatasetComponent,
  TransformComponent,
  LegendComponent,
} from 'echarts/components';
// 标签自动布局，全局过渡动画等特性
import { LabelLayout, UniversalTransition } from 'echarts/features';
// 引入 Canvas 渲染器，注意引入 CanvasRenderer 或者 SVGRenderer 是必须的一步
import { SVGRenderer } from 'echarts/renderers';

// 注册必须的组件
echarts.use([
  TitleComponent,
  TooltipComponent,
  GridComponent,
  DatasetComponent,
  TransformComponent,
  BarChart,
  PieChart,
  LabelLayout,
  UniversalTransition,
  SVGRenderer,
  LegendComponent,
]);

import Styles from './style.less';

export default forwardRef((props, ref) => {
  const domRef = useRef();
  const echartsRef = useRef();

  useEffect(() => {
    echartsRef.current = echarts.init(domRef.current);
    window.onresize = function () {
      echartsRef.current.resize();
    };

    return () => echartsRef.current.dispose();
  }, []);

  useEffect(() => {
    if (echartsRef.current) {
      echartsRef.current.setOption(props.option);
    }
  }, [props.option]);

  useEffect(() => {
    if (echartsRef.current) {
      if (props.loading) {
        echartsRef.current.showLoading();
      } else {
        echartsRef.current.hideLoading();
      }
    }
  }, [props.loading]);

  useImperativeHandle(ref, () => ({
    echart: echartsRef,
  }));

  const classList = classNames(Styles.echart, props.className);

  return <div className={classList} ref={domRef} />;
});
