import { useEffect, useState, forwardRef, useImperativeHandle, useRef } from 'react';
import { Table, Space, Button, Popconfirm } from 'antd';
import { getList, remove } from '@/services/extendContent';

export default forwardRef((props, ref) => {
  const { targetType, targetId, onEdit } = props;

  const [loading, setLoading] = useState(false);
  const [list, setList] = useState([]);
  const refs = useRef();

  const tableList = () => {
    setLoading(true);
    getList({
      pageSize: 9999,
      targetId,
      targetType,
    })
      .then((res) => {
        setList(res.records || []);
        setLoading(false);
      })
      .catch(() => setLoading(false));
  };

  refs.current = tableList;

  // 父组件调用 updateList 来修改 list
  useImperativeHandle(ref, () => ({
    reload: refs.current,
    setLoading,
  }));

  const handleEdit = (record) => {
    onEdit(record);
  };
  //删除
  const handleDelete = (record) => {
    setLoading(true);
    remove(record.extId)
      .then(() => {
        setList(list.filter((x) => x.extId !== record.extId));
        setLoading(false);
        // refs.current.reload();
      })
      .catch(() => setLoading(false));
  };

  const columns = [
    {
      title: '序号',
      key: 'index',
      dataIndex: 'index',
      render: (t, record, index) => `${index + 1}`,
    },
    {
      title: '权重',
      key: 'sort',
      dataIndex: 'sort',
      render: (t, record) => `${record.sort}`,
    },
    {
      title: '内容',
      key: 'content',
      dataIndex: 'content',
      ellipsis: true,
      render: (t, record) => {
        if (record.contentType === 'text') return t;
        if (record.contentType === 'image') {
          return <img style={{ width: '110px' }} src={t} alt="" />;
        }
      },
    },
    {
      title: '操作',
      key: 'option',
      render: (_, record) => {
        return (
          <Space>
            <Button type="link" onClick={() => handleEdit(record)}>
              编辑
            </Button>
            {/* <Button type="link" onClick={() => handleEdit(record)}>插入</Button> */}
            <Popconfirm title="确定进行当前操作 ?" onConfirm={() => handleDelete(record)}>
              <Button type="link">删除</Button>
            </Popconfirm>
          </Space>
        );
      },
    },
  ];

  useEffect(() => {
    if (targetType) {
      refs.current();
    }
  }, [targetType]);
  return (
    <Table
      loading={loading}
      rowKey="extId"
      columns={columns}
      dataSource={list}
      pagination={false}
    />
  );
});
