import { useEffect, useImperativeHandle, useState, forwardRef } from 'react';
import { Button } from 'antd';
import ModalText from './ModalText';
import ModalImage from './Modalimage';

export default forwardRef((props, ref) => {
  const { contentType, record, onChange, onClose, ...btnProps } = props;

  const [visible, setVisible] = useState(false);
  const [content, setContent] = useState();
  const [sortVale, setSortVale] = useState();

  const handleClose = () => {
    setContent();
    setSortVale();
    setVisible(false);
    onClose();
  };

  const handleChange = (val, e) => {
    onChange(
      {
        ...(record || {}),
        content: val,
        sort: e - 0,
        contentType,
      },
      handleClose,
    );
  };

  useImperativeHandle(ref, () => ({
    toggle: () => {
      setVisible(!visible);
    },
  }));

  useEffect(() => {
    setContent(record?.content);
    setSortVale(record?.sort);
  }, [record, visible]);

  return (
    <>
      <Button onClick={() => setVisible(true)} {...btnProps}>
        {props.children}
      </Button>
      {contentType === 'text' && (
        <ModalText
          sortVale={sortVale}
          visible={visible}
          value={content}
          onChange={handleChange}
          onCancel={handleClose}
        />
      )}
      {contentType === 'image' && (
        <ModalImage
          sortVale={sortVale}
          visible={visible}
          value={content}
          onChange={handleChange}
          onCancel={handleClose}
        />
      )}
    </>
  );
});
