import { Button, message, Space } from 'antd';
import { PlusOutlined } from '@ant-design/icons';
import { useRef, useState } from 'react';
import ModalButton from './ModalButton';
import List from './List';
import { save, update } from '@/services/extendContent';

export default (props) => {
  const { onCancel, targetId, targetType } = props;

  const [record, setRecord] = useState();
  const listRef = useRef();
  const textBtnRef = useRef();
  const imageBtnRef = useRef();
  const videoBtnRef = useRef();

  const handleChange = (row, next) => {
    const data = {
      ...(row || {}),
      targetId,
      targetType,
    };

    if (data.extId) {
      // 编辑提交

      update(data.extId, data).then(() => {
        listRef.current.reload();
        next();

        message.success('更新数据成功');
      });
    } else if (data.content) {
      // 新增提交
      listRef.current.setLoading(true);
      save(data).then((res) => {
        listRef.current.reload();
        next();

        message.success('保存数据成功');
      });
    } else {
      next();
    }
  };

  const handleEdit = (row) => {
    setRecord(row);
    switch (row.contentType) {
      case 'text':
        textBtnRef.current.toggle();
        break;
      case 'image':
        imageBtnRef.current.toggle();
        break;
      case 'video':
        videoBtnRef.current.toggle();
        break;
      default:
        break;
    }
  };

  const handleClose = () => {
    setRecord();
  };

  return (
    <div>
      <Space size="large" style={{ marginBottom: '18px' }}>
        <ModalButton
          ref={textBtnRef}
          type="dashed"
          icon={<PlusOutlined />}
          record={record}
          contentType="text"
          onChange={handleChange}
          onClose={handleClose}
        >
          文字
        </ModalButton>
        <ModalButton
          ref={imageBtnRef}
          type="dashed"
          icon={<PlusOutlined />}
          record={record}
          contentType="image"
          onChange={handleChange}
          onClose={handleClose}
        >
          图片
        </ModalButton>
      </Space>
      <List ref={listRef} targetType={targetType} onEdit={handleEdit} targetId={targetId} />
      {/* <Button onClick={onCancel} style={{ marginTop: '2em', float: 'right' }}>
        返回
      </Button> */}
    </div>
  );
};
