import React, { useRef } from 'react';
import { history } from 'umi';
import { Button, Popconfirm, message, Select, Modal } from 'antd';
import { PlusOutlined } from '@ant-design/icons';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import PageTable from '@/components/PageTable';
import { getMachineryList, deleteMachinery, updateMachinery } from '@/services/machinery';

const { Option } = Select;

export default (props) => {
  const actionRef = useRef();

  const gotoEdit = (id) => {
    const queryStr = id ? `?id=${id}` : '';
    history.push(`./machinery/edit.jsx${queryStr}`);
  };
  const handleDelete = (id) => {
    deleteMachinery(id).then(() => {
      message.success('删除成功');
      actionRef.current.reload();
    });
  };
  //列表切换农机状态方法
  const handleOK = (record, data) => {
    const title = record.status
      ? '您确定要将该农机状态变更为禁用吗? 禁用后该农机将不在移动端显示'
      : '您确定要将该农机状态变更为启用吗? 启用后该农机可以在移动端显示';
    Modal.confirm({
      title: title,
      okText: '确认',
      cancelText: '取消',
      onOk() {
        updateMachinery(record.machineryId, { ...record, status: record.status === 1 ? 0 : 1 })
          .then((res) => {
            message.success('操作成功');
            actionRef.current.reload();
          })
          .catch((err) => {
            message.error(err);
          });
      },
    });
  };
  const actions = () => [
    <Button key="add" type="primary" icon={<PlusOutlined />} onClick={() => gotoEdit()}>
      新增农机
    </Button>,
  ];
  const columns = [
    {
      title: '名称',
      dataIndex: 'name',
      key: 'name',
    },
    {
      title: '农机类型',
      dataIndex: 'typeName',
      key: 'typeName',
    },
    {
      title: '农机归属',
      dataIndex: 'regionName',
      key: 'regionName',
    },
    {
      title: '农机价格',
      dataIndex: 'price',
      key: 'price',
      search: false,
    },
    {
      title: '人工费',
      dataIndex: 'laborCost',
      key: 'laborCost',
      search: false,
    },
    {
      title: '押金',
      dataIndex: 'deposit',
      key: 'deposit',
      search: false,
    },
    {
      title: '主图',
      dataIndex: 'thumb',
      key: 'thumb',
      width: 150,
      render: (t) => <img width={110} src={t} alt="" />,
      search: false,
    },
    {
      title: '工作状态',
      dataIndex: 'jobStatus',
      key: 'jobStatus',
      renderFormItem: (item, field, form) => {
        return (
          <Select>
            <Option value="1">忙碌</Option>
            <Option value="0">空闲</Option>
          </Select>
        );
      },
      render: (_, record) => {
        return record.jobStatus === 1 ? '忙碌' : '空闲';
      },
    },
    {
      title: '发布状态',
      dataIndex: 'status',
      key: 'status',
      renderFormItem: (item, field, form) => {
        return (
          <Select>
            <Option value="1">发布</Option>
            <Option value="0">未发布</Option>
          </Select>
        );
      },
      render: (_, record) => {
        return record.status === 1 ? '发布' : '未发布';
      },
    },
    {
      title: '操作',
      valueType: 'option',
      render: (_, record) => [
        <Button style={{ padding: 0 }} type="link" key={1} onClick={() => handleOK(record)}>
          {record.status === 0 ? '发布' : '取消发布'}
        </Button>,
        <Button
          style={{ padding: 0 }}
          type="link"
          key={2}
          onClick={() => gotoEdit(record.machineryId)}
        >
          编辑
        </Button>,
        <Popconfirm
          key={3}
          title="您是否确认删除 ?"
          onConfirm={() => handleDelete(record.machineryId)}
          okText="确定"
          cancelText="取消"
        >
          <Button style={{ padding: 0 }} type="link">
            删除
          </Button>
        </Popconfirm>,
      ],
    },
  ];

  return (
    <PageHeaderWrapper>
      <PageTable
        request={getMachineryList}
        // expfunc={exportPersonList}
        toolBarRender={actions}
        actionRef={actionRef}
        columns={columns}
        rowKey="machineryId"
        options={false}
        scroll={{ x: 1000 }}
      />
    </PageHeaderWrapper>
  );
};
